@@ -4,10 +4,11 @@ use strict;
 use warnings;
 
 use Crypt::NSS::X509;
+use Carp;
 
 use MIME::Base64 ();
 
-our $VERSION = '0.03_03';
+our $VERSION = '0.04';
 
 sub new_from_pem {
 	my $class = shift;
